========
BigQuery
========

BigqueryUtility
---------------

.. autoclass:: gwrappy.bigquery.BigqueryUtility
    :members:


Misc Classes/Functions
----------------------

.. autoclass:: gwrappy.bigquery.utils.JobResponse
    :members:

.. autoclass:: gwrappy.bigquery.utils.TableResponse
    :members:

.. automodule:: gwrappy.bigquery.utils
    :members:
